/**
 * Implementation of the `fetchText` and `writeText` callbacks.
 *
 * @packageDocumentation
 */

import { FetchText } from '@acoustic-content-sdk/rest-api';
import { LoggerService } from '@acoustic-content-sdk/api';
import { StaticHubInfoUrlProvider } from '@acoustic-content-sdk/api';
import { WriteText } from '@acoustic-content-sdk/rest-api';

/**
 * Creates a callback function that loads content via HTTP GET from the API routes.
 *
 * @param apiBase - the {@link https://developer.ibm.com/customer-engagement/tutorials/accessing-your-sites-through-watson-content-hub-apis/#tocstep1 | API URL}.
 * @param logger - an optional logger
 * @returns the callback function
 */
export declare function fetchTextAjax(apiBase: StaticHubInfoUrlProvider | PromiseLike<StaticHubInfoUrlProvider>, aLoggerService?: LoggerService): FetchText;

/** Version and build number of the package */
export declare const VERSION: {
    version: {
        major: string;
        minor: string;
        patch: string;
        branch: string;
    };
    build: Date;
};

/**
 * Creates a callback function that writes content to API routes via PUST, POST or delete
 *
 * @param apiBase - the {@link https://developer.ibm.com/customer-engagement/tutorials/accessing-your-sites-through-watson-content-hub-apis/#tocstep1 | API URL}.
 * @param logger - an optional logger
 * @returns the callback function
 */
export declare function writeJsonAjax(apiBase: StaticHubInfoUrlProvider | PromiseLike<StaticHubInfoUrlProvider>, aLoggerService?: LoggerService): WriteText;

export { }
